# elastic-tables

Format text using elastic tabstops

[![Python package](https://github.com/deffi/elastic-tables/actions/workflows/python-package.yml/badge.svg)](https://github.com/deffi/elastic-tables/actions/workflows/python-package.yml)

Required Python version is 3.8
